@@ -8,11 +8,13 @@ function(
 	...	#aditional parameters to "plot.mat"
 ){
 	if(is.null(main)) main <- deparse(substitute(x))
-	if(which>length(x$best)){
+	l<-length(x$best)
+	if(l==0)l<-1
+	if(which>l){
 		warning("The selected (",which,") best solution does not exist!\nOnly ", length(x$best)," best solution(s) exist(s).\nThe first best solution will be ploted.\n")
 		which<-1
 	}
-	plot.mat(x$M,clu=x$best[[which]]$clu,IM=x$best[[which]]$IM,main=main,...)
+	plot.mat(x$M,clu=clu(x,which=which),IM=IM(x,which=which),main=main,...)
 }
 
 #' @rdname plotMat
